/**
 * 公共函数库
 * kevinE qq:202165023
 * v2.0 2022-4-28 08:42:32
 */

/**
 * @description 模拟线程阻塞
 * @param {Number} sto 等待时长 毫秒
 * @param {Function} [func] 预执行函数
 * @example sleep(1000).then(res => { // do sth. });
 */
async function sleep(sto, func) {
	let res;
	if (!!func) res = func();
	return await new Promise((resolve, reject) => {
		setTimeout(() => {
			resolve(res);
		}, sto);
	});
}

/**
 * @description 异步获取设备信息
 * @return {JSON} 设备信息
 * @example getDeviceInfo().then(res => { // do sth. });
 */
async function getDeviceInfo() {
	if (!window.plus) return;

	// 存储数据
	let data = {};
	// 身份信息
	plus.device.getInfo({
		success: (res) => {
			data.imei = res.imei;
			data.imsi = res.imsi;
			data.uuid = res.uuid;
		},
		fail: (err) => {
			data.imei = err.message;
			data.imsi = err.message;
			data.uuid = err.message;
		}
	});
	plus.device.getOAID({
		success: (res) => {
			data.oaid = res.oaid;
		},
		fail: (err) => {
			data.oaid = err.message;
		}
	});
	plus.device.getVAID({
		success: (res) => {
			data.vaid = res.vaid;
		},
		fail: (err) => {
			data.vaid = err.message;
		}
	});
	plus.device.getAAID({
		success: (res) => {
			data.aaid = res.aaid;
		},
		fail: (err) => {
			data.aaid = err.message;
		}
	});

	// 屏幕信息
	// 水平方向的密度
	data.dpiX = plus.screen.dpiX;
	// 垂直方向的密度
	data.dpiY = plus.screen.dpiY;
	// 屏幕宽度物理分辨率
	data.width = plus.screen.width;
	// 屏幕高度物理分辨率
	data.height = plus.screen.height;
	// 屏幕宽度逻辑分辨率
	data.resolutionWidth = plus.screen.resolutionWidth;
	// 屏幕高度逻辑分辨率
	data.resolutionHeight = plus.screen.resolutionHeight;
	// 获取系统状态栏高度，单位为像素（px），值为Webview中的逻辑高度单位
	data.statusbarHeight = plus.navigator.getStatusbarHeight();
	// 逻辑分辨率与物理分辨率的缩放比例
	data.scale = plus.screen.scale;
	// 应用可使用的屏幕宽度逻辑分辨率
	data._resolutionWidth = plus.display.resolutionWidth;
	// 应用可使用的屏幕高度逻辑分辨率
	data._resolutionHeight = plus.display.resolutionHeight;

	// 网络信息
	const type = ['UNKNOW', 'NONE', 'ETHERNET', 'WIFI', '2G', '3G', '4G', '5G'];
	let net = plus.networkinfo.getCurrentType();
	data.network = type[net];

	// 系统信息
	data.name = plus.os.name;
	data.version = plus.os.version;
	data.language = plus.os.language;
	data.vendor = plus.os.vendor;

	// 浏览器信息
	// 是否为刘海屏，仅支持华为、小米、Oppo、Vivo等品牌设备
	data.hasNotchInScreen = plus.navigator.hasNotchInScreen();
	// 设备是否被root破解
	data.isRoot = plus.navigator.isRoot();
	// 应用是否运行在模拟器中
	data.isSimulator = plus.navigator.isSimulator();
	// 系统状态栏高度
	data.statusbarHeight = plus.navigator.getStatusbarHeight();
	// 获取userAgent值
	data.userAgent = plus.navigator.getUserAgent();
	// 获取应用的安全区域[]
	data.safeAreaInsets = plus.navigator.getSafeAreaInsets();
	// 返回数据
	return sleep(10).then(() => {
		return data
	});
}

/**
 * @description 异步获取位置信息
 * @return {JSON} 位置信息
 * @example getGEO().then(res => { // do sth. });
 */
async function getGEO() {
	if (!window.plus) return;
	let data = {}
	plus.geolocation.getCurrentPosition(res => {
		data = res;
		// console.log(JSON.stringify(res));
		// {"coordsType":"wgs84","coords":{"latitude":39.915,"longitude":116.404,"accuracy":0.02063,"altitude":0,"heading":0.02084,"speed":0.02078,"altitudeAccuracy":0},"timestamp":null}
	}, err => {
		data = err;
		// console.log(JSON.stringify(err));
		// {"code":2,"message":"get location fail."}
	}, {
		provider: "baidu",
		enableHighAccuracy: true,
		geocode: true
	});
	return sleep(3000).then(() => {
		return data
	});
}

/**
 * @description 获取页面ID节点
 * @param {IDString} id 页面节点ID
 * @return {HTMLElement} 页面节点
 */
function $(id) {
	return document.getElementById(id);
}

/**
 * @description 获取网络状态
 * @return {String} 网络状态['UNKNOW', 'NONE', 'ETHERNET', 'WIFI', '2G', '3G', '4G', '5G']
 */
function networkName() {
	if (!window.plus) return;
	const type = ['UNKNOW', 'NONE', 'ETHERNET', 'WIFI', '2G', '3G', '4G', '5G'];
	let net = plus.networkinfo.getCurrentType();
	return type[net];
}

function HTMLEnCode(str) {
	var s = "";
	if (str.length == 0) return "";
	s = str.replace(/</g, "&lt;");
	s = s.replace(/>/g, "&gt;");
	s = s.replace(/&/g, "&amp;");
	s = s.replace(/\'/g, "&apos;");
	s = s.replace(/\"/g, "&quot;");
	s = s.replace(/\n/g, "&nbsp;");
	s = s.replace(/\r/g, "&nbsp;");
	s = s.replace(/\r\n/g, "&nbsp;");
	s = s.replace(/\n\r/g, "&nbsp;");
	return s;
}
